export interface URLDataSyncInProps<Data> {
    readonly data: Data;
    readonly dataError: Error | null | undefined;
    readonly isLoadingData: boolean;
    readonly urlQuery: URLQueryMap;
    getData(): void;
    saveData(): void;
    updateData(data: Partial<Data>): void;
    /** Update URL query parameters without reloading and trigger a re-sync. */
    updateURLQuery(...queries: readonly URLQueryMap[]): void;
}
export interface URLDataSyncOutProps<Data> {
    readonly initialData: Data;
    readonly urlDataSync: Repository.URLDataSync;
}
/**
 * Automatically sync with current URL by requesting data from server using
 * said URL. This is assuming there is data provided by the server at current
 * URL, e.g. user navigates to /users/1, this will send a GET request to
 * /users/1, which should have a defined backend route that contains the
 * relevant data.
 *
 * This HOC is usually used for components rendered by a Route. Please make sure
 * when implementing the backend to handle these requests that it never returns
 * null/undefined (as per REST design standards).
 */
export declare function urlDataSync<Data, OutProps = {}>(): FunctionalEnhancer<URLDataSyncInProps<Data> & OutProps, URLDataSyncOutProps<Data> & OutProps>;
export interface CursorPaginatedData<T> {
    readonly results: readonly T[];
    readonly next?: string;
    readonly previous?: string;
}
export interface CursorPaginationInProps<T> {
    readonly next?: string;
    readonly previous?: string;
    setNext(next?: string): void;
    setPrevious(previous?: string): void;
}
/**
 * This works with the auto-sync HOC to provide pagination state (but does not
 * trigger the sync). It is assumed that the server will return the data in the
 * above format - the cursor markers will be stored internally and fed the next
 * time we perform a GET request.
 */
export declare function cursorPagination<T, OutProps = {}>(): FunctionalEnhancer<CursorPaginationInProps<T> & OutProps, OutProps>;
export interface URLCursorPaginatedDataSyncInProps<T> extends URLDataSyncInProps<CursorPaginatedData<T>> {
    goToNextPage(): void;
    goToPreviousPage(): void;
}
export interface URLCursorPaginatedDataSyncOutProps<T> extends URLDataSyncOutProps<CursorPaginatedData<T>> {
}
/**
 * This HOC automatically manages pagination data sync, and is best used to
 * display table data. For other kinds of data use the data sync HOC.
 */
export declare function urlCursorPaginatedDataSync<T>(): FunctionalEnhancer<URLDataSyncInProps<readonly T[]> & Pick<URLCursorPaginatedDataSyncInProps<any>, "goToNextPage" | "goToPreviousPage">, Pick<URLCursorPaginatedDataSyncOutProps<T>, "urlDataSync">>;
//# sourceMappingURL=dataHOC.d.ts.map